==> gliv_1.9.1.orig.tar.gz: gliv-1.9.1/src/include/all_cursors.h <==
#define cursor_move_width 20
#define cursor_move_height 20
#define cursor_move_x_hot 10
#define cursor_move_y_hot 10
static char cursor_move_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x04, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x1f, 0x00, 0x00, 0x04, 0x00,
    0x40, 0x44, 0x00, 0x60, 0xc4, 0x00, 0xf0, 0xff, 0x01, 0x60, 0xc4, 0x00,
    0x40, 0x44, 0x00, 0x00, 0x04, 0x00, 0x00, 0x1f, 0x00, 0x00, 0x0e, 0x00,
    0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
};
#define cursor_move_mask_width 20
#define cursor_move_mask_height 20
static char cursor_move_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00,
    0x00, 0x0e, 0x00, 0x00, 0x1f, 0x00, 0x80, 0x3f, 0x00, 0x40, 0x5f, 0x00,
    0xe0, 0xee, 0x00, 0xf0, 0xff, 0x01, 0xf8, 0xff, 0x03, 0xf0, 0xff, 0x01,
    0xe0, 0xee, 0x00, 0x40, 0x5f, 0x00, 0x80, 0x3f, 0x00, 0x00, 0x1f, 0x00,
    0x00, 0x0e, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
};
#define cursor_rect_zoom_width 20
#define cursor_rect_zoom_height 20
#define cursor_rect_zoom_x_hot 9
#define cursor_rect_zoom_y_hot 9
static char cursor_rect_zoom_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x80, 0x07, 0x00, 0x40, 0x08, 0x00, 0x20, 0x10, 0x00, 0x10, 0x20, 0x00,
    0x10, 0x20, 0x00, 0x10, 0x20, 0x00, 0x10, 0x20, 0x00, 0x20, 0x10, 0x00,
    0x40, 0x38, 0x00, 0x80, 0x77, 0x00, 0x00, 0xe0, 0x00, 0x00, 0xc0, 0x01,
    0x00, 0x80, 0x03, 0x00, 0x00, 0x07, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00,
};
#define cursor_rect_zoom_mask_width 20
#define cursor_rect_zoom_mask_height 20
static char cursor_rect_zoom_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x00,
    0xc0, 0x0f, 0x00, 0xe0, 0x1f, 0x00, 0x70, 0x38, 0x00, 0x38, 0x70, 0x00,
    0x38, 0x70, 0x00, 0x38, 0x70, 0x00, 0x38, 0x70, 0x00, 0x70, 0x38, 0x00,
    0xe0, 0x7f, 0x00, 0xc0, 0xff, 0x00, 0x80, 0xf7, 0x01, 0x00, 0xe0, 0x03,
    0x00, 0xc0, 0x07, 0x00, 0x80, 0x0f, 0x00, 0x00, 0x07, 0x00, 0x00, 0x02,
};
#define cursor_rotate_width 20
#define cursor_rotate_height 20
#define cursor_rotate_x_hot 12
#define cursor_rotate_y_hot 11
static char cursor_rotate_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00,
    0x40, 0xdc, 0x01, 0xc0, 0x06, 0x03, 0x40, 0x03, 0x06, 0x40, 0x02, 0x04,
    0x40, 0x04, 0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0xe0, 0x07, 0x00, 0x40, 0x04, 0x40, 0x80, 0x04, 0xc0, 0x80, 0x05,
    0x80, 0xc1, 0x06, 0x00, 0x77, 0x04, 0x00, 0x1c, 0x00, 0x00, 0x00, 0x00,
};
#define cursor_rotate_mask_width 20
#define cursor_rotate_mask_height 20
static char cursor_rotate_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x60, 0xfc, 0x01,
    0xe0, 0xfe, 0x03, 0xe0, 0xdf, 0x07, 0xe0, 0x07, 0x0f, 0xe0, 0x07, 0x0e,
    0xe0, 0x0f, 0x04, 0xe0, 0x1f, 0x00, 0xe0, 0x1f, 0x00, 0x00, 0xf0, 0x0f,
    0x00, 0xf0, 0x0f, 0x40, 0xe0, 0x0f, 0xe0, 0xc0, 0x0f, 0xe0, 0xc1, 0x0f,
    0xc0, 0xf7, 0x0f, 0x80, 0xff, 0x0e, 0x00, 0x7f, 0x0c, 0x00, 0x1c, 0x00,
};
#define cursor_zoom_width 20
#define cursor_zoom_height 20
#define cursor_zoom_x_hot 9
#define cursor_zoom_y_hot 9
static char cursor_zoom_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x80, 0x07, 0x00, 0x40, 0x08, 0x00, 0x20, 0x10, 0x00, 0x10, 0x20, 0x00,
    0x10, 0x20, 0x00, 0x10, 0x20, 0x00, 0x10, 0x20, 0x00, 0x20, 0x10, 0x00,
    0x40, 0x38, 0x00, 0x80, 0x77, 0x00, 0x00, 0xe0, 0x00, 0x00, 0xc0, 0x01,
    0x00, 0x80, 0x03, 0x00, 0x00, 0x07, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00,
};
#define cursor_zoom_mask_width 20
#define cursor_zoom_mask_height 20
static char cursor_zoom_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x00,
    0xc0, 0x0f, 0x00, 0xe0, 0x1f, 0x00, 0x70, 0x38, 0x00, 0x38, 0x70, 0x00,
    0x38, 0x70, 0x00, 0x38, 0x70, 0x00, 0x38, 0x70, 0x00, 0x70, 0x38, 0x00,
    0xe0, 0x7f, 0x00, 0xc0, 0xff, 0x00, 0x80, 0xf7, 0x01, 0x00, 0xe0, 0x03,
    0x00, 0xc0, 0x07, 0x00, 0x80, 0x0f, 0x00, 0x00, 0x07, 0x00, 0x00, 0x02,
};
#define cursor_zoom_rotate_width 20
#define cursor_zoom_rotate_height 20
#define cursor_zoom_rotate_x_hot 12
#define cursor_zoom_rotate_y_hot 11
static unsigned char cursor_zoom_rotate_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00,
    0xc0, 0xdf, 0x01, 0xc0, 0x0e, 0x03, 0x60, 0x13, 0x06, 0x50, 0x22, 0x04,
    0x50, 0x24, 0x00, 0xd0, 0x2f, 0x00, 0x10, 0x20, 0x00, 0x20, 0x10, 0x00,
    0x40, 0xf8, 0x07, 0x80, 0x77, 0x04, 0x40, 0xe0, 0x04, 0xc0, 0xc0, 0x05,
    0x80, 0xc1, 0x07, 0x00, 0x77, 0x07, 0x00, 0x1c, 0x02, 0x00, 0x00, 0x00
};
#define cursor_zoom_rotate_mask_width 20
#define cursor_zoom_rotate_mask_height 20
static unsigned char cursor_zoom_rotate_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0xe0, 0xff, 0x01,
    0xe0, 0xff, 0x03, 0xe0, 0xdf, 0x07, 0xf0, 0x3f, 0x0f, 0xf8, 0x77, 0x0e,
    0xf8, 0x7f, 0x04, 0xf8, 0x7f, 0x00, 0xf8, 0x7f, 0x00, 0x70, 0xf8, 0x0f,
    0xe0, 0xff, 0x0f, 0xc0, 0xff, 0x0f, 0xe0, 0xf7, 0x0f, 0xe0, 0xe1, 0x0f,
    0xc0, 0xf7, 0x0f, 0x80, 0xff, 0x0f, 0x00, 0x7f, 0x0f, 0x00, 0x1c, 0x02
};

==> gliv_1.9.3.orig.tar.gz: gliv-1.9.3/src/include/all_cursors.h <==
#define cursor_move_width 20
#define cursor_move_height 20
#define cursor_move_x_hot 10
#define cursor_move_y_hot 10
static unsigned char cursor_move_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x04, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x1f, 0x00, 0x00, 0x04, 0x00,
    0x40, 0x44, 0x00, 0x60, 0xc4, 0x00, 0xf0, 0xff, 0x01, 0x60, 0xc4, 0x00,
    0x40, 0x44, 0x00, 0x00, 0x04, 0x00, 0x00, 0x1f, 0x00, 0x00, 0x0e, 0x00,
    0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
};
#define cursor_move_mask_width 20
#define cursor_move_mask_height 20
static unsigned char cursor_move_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00,
    0x00, 0x0e, 0x00, 0x00, 0x1f, 0x00, 0x80, 0x3f, 0x00, 0x40, 0x5f, 0x00,
    0xe0, 0xee, 0x00, 0xf0, 0xff, 0x01, 0xf8, 0xff, 0x03, 0xf0, 0xff, 0x01,
    0xe0, 0xee, 0x00, 0x40, 0x5f, 0x00, 0x80, 0x3f, 0x00, 0x00, 0x1f, 0x00,
    0x00, 0x0e, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
};
#define cursor_rect_zoom_width 20
#define cursor_rect_zoom_height 20
#define cursor_rect_zoom_x_hot 9
#define cursor_rect_zoom_y_hot 9
static unsigned char cursor_rect_zoom_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x80, 0x07, 0x00, 0x40, 0x08, 0x00, 0x20, 0x10, 0x00, 0x10, 0x20, 0x00,
    0x10, 0x20, 0x00, 0x10, 0x20, 0x00, 0x10, 0x20, 0x00, 0x20, 0x10, 0x00,
    0x40, 0x38, 0x00, 0x80, 0x77, 0x00, 0x00, 0xe0, 0x00, 0x00, 0xc0, 0x01,
    0x00, 0x80, 0x03, 0x00, 0x00, 0x07, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00,
};
#define cursor_rect_zoom_mask_width 20
#define cursor_rect_zoom_mask_height 20
static unsigned char cursor_rect_zoom_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x00,
    0xc0, 0x0f, 0x00, 0xe0, 0x1f, 0x00, 0x70, 0x38, 0x00, 0x38, 0x70, 0x00,
    0x38, 0x70, 0x00, 0x38, 0x70, 0x00, 0x38, 0x70, 0x00, 0x70, 0x38, 0x00,
    0xe0, 0x7f, 0x00, 0xc0, 0xff, 0x00, 0x80, 0xf7, 0x01, 0x00, 0xe0, 0x03,
    0x00, 0xc0, 0x07, 0x00, 0x80, 0x0f, 0x00, 0x00, 0x07, 0x00, 0x00, 0x02,
};
#define cursor_rotate_width 20
#define cursor_rotate_height 20
#define cursor_rotate_x_hot 12
#define cursor_rotate_y_hot 11
static unsigned char cursor_rotate_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00,
    0x40, 0xdc, 0x01, 0xc0, 0x06, 0x03, 0x40, 0x03, 0x06, 0x40, 0x02, 0x04,
    0x40, 0x04, 0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0xe0, 0x07, 0x00, 0x40, 0x04, 0x40, 0x80, 0x04, 0xc0, 0x80, 0x05,
    0x80, 0xc1, 0x06, 0x00, 0x77, 0x04, 0x00, 0x1c, 0x00, 0x00, 0x00, 0x00,
};
#define cursor_rotate_mask_width 20
#define cursor_rotate_mask_height 20
static unsigned char cursor_rotate_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x60, 0xfc, 0x01,
    0xe0, 0xfe, 0x03, 0xe0, 0xdf, 0x07, 0xe0, 0x07, 0x0f, 0xe0, 0x07, 0x0e,
    0xe0, 0x0f, 0x04, 0xe0, 0x1f, 0x00, 0xe0, 0x1f, 0x00, 0x00, 0xf0, 0x0f,
    0x00, 0xf0, 0x0f, 0x40, 0xe0, 0x0f, 0xe0, 0xc0, 0x0f, 0xe0, 0xc1, 0x0f,
    0xc0, 0xf7, 0x0f, 0x80, 0xff, 0x0e, 0x00, 0x7f, 0x0c, 0x00, 0x1c, 0x00,
};
#define cursor_zoom_width 20
#define cursor_zoom_height 20
#define cursor_zoom_x_hot 9
#define cursor_zoom_y_hot 9
static unsigned char cursor_zoom_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x80, 0x07, 0x00, 0x40, 0x08, 0x00, 0x20, 0x10, 0x00, 0x10, 0x20, 0x00,
    0x10, 0x20, 0x00, 0x10, 0x20, 0x00, 0x10, 0x20, 0x00, 0x20, 0x10, 0x00,
    0x40, 0x38, 0x00, 0x80, 0x77, 0x00, 0x00, 0xe0, 0x00, 0x00, 0xc0, 0x01,
    0x00, 0x80, 0x03, 0x00, 0x00, 0x07, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00,
};
#define cursor_zoom_mask_width 20
#define cursor_zoom_mask_height 20
static unsigned char cursor_zoom_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x00,
    0xc0, 0x0f, 0x00, 0xe0, 0x1f, 0x00, 0x70, 0x38, 0x00, 0x38, 0x70, 0x00,
    0x38, 0x70, 0x00, 0x38, 0x70, 0x00, 0x38, 0x70, 0x00, 0x70, 0x38, 0x00,
    0xe0, 0x7f, 0x00, 0xc0, 0xff, 0x00, 0x80, 0xf7, 0x01, 0x00, 0xe0, 0x03,
    0x00, 0xc0, 0x07, 0x00, 0x80, 0x0f, 0x00, 0x00, 0x07, 0x00, 0x00, 0x02,
};
#define cursor_zoom_rotate_width 20
#define cursor_zoom_rotate_height 20
#define cursor_zoom_rotate_x_hot 12
#define cursor_zoom_rotate_y_hot 11
static unsigned char cursor_zoom_rotate_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00,
    0xc0, 0xdf, 0x01, 0xc0, 0x0e, 0x03, 0x60, 0x13, 0x06, 0x50, 0x22, 0x04,
    0x50, 0x24, 0x00, 0xd0, 0x2f, 0x00, 0x10, 0x20, 0x00, 0x20, 0x10, 0x00,
    0x40, 0xf8, 0x07, 0x80, 0x77, 0x04, 0x40, 0xe0, 0x04, 0xc0, 0xc0, 0x05,
    0x80, 0xc1, 0x07, 0x00, 0x77, 0x07, 0x00, 0x1c, 0x02, 0x00, 0x00, 0x00
};
#define cursor_zoom_rotate_mask_width 20
#define cursor_zoom_rotate_mask_height 20
static unsigned char cursor_zoom_rotate_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0xe0, 0xff, 0x01,
    0xe0, 0xff, 0x03, 0xe0, 0xdf, 0x07, 0xf0, 0x3f, 0x0f, 0xf8, 0x77, 0x0e,
    0xf8, 0x7f, 0x04, 0xf8, 0x7f, 0x00, 0xf8, 0x7f, 0x00, 0x70, 0xf8, 0x0f,
    0xe0, 0xff, 0x0f, 0xc0, 0xff, 0x0f, 0xe0, 0xf7, 0x0f, 0xe0, 0xe1, 0x0f,
    0xc0, 0xf7, 0x0f, 0x80, 0xff, 0x0f, 0x00, 0x7f, 0x0f, 0x00, 0x1c, 0x02
};
